==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/autoaway/translations/autoaway_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Comprobar inactividad despues</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Establecer estado a ausente despues de</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Establecer estado a invisible después de</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Sustituir</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nueva descripción</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Establecer estado a ausencia prolongada despues de</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n segundo</numerusform>
            <numerusform>%n segundos</numerusform>
        </translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>No Cambiar</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <source>Inactivity</source>
        <translation>Inactividad</translation>
    </message>
    <message>
        <source>Refresh status every</source>
        <translation>Actualizar el estado cada</translation>
    </message>
    <message>
        <source>Switch to &apos;away&apos;</source>
        <translation>Cambiar a &apos;ausente&apos;</translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation>
            <numerusform>%n minuto(s)</numerusform>
            <numerusform>%n minuto(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>Switch to &apos;auto extended away&apos;</source>
        <translation>Cambiar a  &apos;ausencia prolongada automática&apos;</translation>
    </message>
    <message>
        <source>Switch to &apos;invisible&apos;</source>
        <translation>Cambiar a &apos;invisible&apos;</translation>
    </message>
    <message>
        <source>Switch to &apos;offline&apos;</source>
        <translation>Cambiar a &apos;desconectado&apos;</translation>
    </message>
    <message>
        <source>Set status to offline after</source>
        <translation>Establecer estado a desconectado después de</translation>
    </message>
    <message>
        <source>Status description when inactive</source>
        <translation>Descripción de estado cuando está inactivo</translation>
    </message>
    <message>
        <source>Prepend</source>
        <translation>Anteponer</translation>
    </message>
    <message>
        <source>Append</source>
        <translation>Adjuntar</translation>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>No actualizar</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/autoaway/translations/autoaway_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Comprobar inactividad despues</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Establecer estado a ausente despues de</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Establecer estado a invisible después de</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Sustituir</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nueva descripción</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Establecer estado a ausencia prolongada despues de</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n segundo</numerusform><numerusform>%n segundos</numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>No Cambiar</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <source>Inactivity</source>
        <translation>Inactividad</translation>
    </message>
    <message>
        <source>Refresh status every</source>
        <translation>Actualizar el estado cada</translation>
    </message>
    <message>
        <source>Switch to &apos;away&apos;</source>
        <translation>Cambiar a &apos;ausente&apos;</translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation><numerusform>%n minuto(s)</numerusform><numerusform>%n minuto(s)</numerusform></translation>
    </message>
    <message>
        <source>Switch to &apos;auto extended away&apos;</source>
        <translation>Cambiar a  &apos;ausencia prolongada automática&apos;</translation>
    </message>
    <message>
        <source>Switch to &apos;invisible&apos;</source>
        <translation>Cambiar a &apos;invisible&apos;</translation>
    </message>
    <message>
        <source>Switch to &apos;offline&apos;</source>
        <translation>Cambiar a &apos;desconectado&apos;</translation>
    </message>
    <message>
        <source>Set status to offline after</source>
        <translation>Establecer estado a desconectado después de</translation>
    </message>
    <message>
        <source>Status description when inactive</source>
        <translation>Descripción de estado cuando está inactivo</translation>
    </message>
    <message>
        <source>Prepend</source>
        <translation>Anteponer</translation>
    </message>
    <message>
        <source>Append</source>
        <translation>Adjuntar</translation>
    </message>
</context>
<context>
    <name>AutoawayConfigurationUiHandler</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>No actualizar</translation>
    </message>
</context>
</TS>
